.. _ydoc directive_2:

``directive_2``
===============

Directive 2 is interpretable as an ordered list of directives

Subdirectives:

.. toctree::
   :maxdepth: 1

   directive_2/directive_2a
   directive_2/directive_2b


----

This page was automatically generated by **ycleptic** v1.8.0 on 2025-08-04.